@@ -1,7 +1,9 @@
 import inspect
+from functools import lru_cache
 from typing import Any, Callable
 
 
+@lru_cache(maxsize=250)
 def get_func_args(func: Callable[[Any], Any]):
     """Returns a list of arguments for the function"""
 
